pub struct DynamicAPIBuilder { /* private fields */ }Expand description
A dynamic API server that can add and remove routes at runtime.
DynamicAPIBuilder serves HTTP and gRPC on a given address, multiplexing both protocols on a single port. Route
additions and removals are handled by subscribing to assertions/retractions of DynamicRoute in the
DataspaceRegistry.
Adding and removing routes
Any process that wants to dynamically register API routes can simply assert a DynamicRoute in the
DataspaceRegistry. Retracting the assertion will remove the route, either when retracted manually or when the
process owning the route assertions exits.
If the dynamic API server is restarted, it will re-register any routes that were previously asserted.
Assertions
BoundApiAddress: the actual listen address bound by the API server. Identifier is"dynamic-<type>-api", wheretypeis the stringified value ofEndpointType::as_str(for example,"dynamic-privileged-api")
Implementations
Sourceimpl DynamicAPIBuilder
impl DynamicAPIBuilder
Sourcepub fn new(endpoint_type: EndpointType, listen_address: ListenAddress) -> Self
pub fn new(endpoint_type: EndpointType, listen_address: ListenAddress) -> Self
Creates a new DynamicAPIBuilder for the given endpoint type and listen address.
Sourcepub fn with_tls_config(self, config: ServerConfig) -> Self
pub fn with_tls_config(self, config: ServerConfig) -> Self
Sets the TLS configuration for the server.
Sourcepub fn with_self_signed_tls(self) -> Self
pub fn with_self_signed_tls(self) -> Self
Sets the TLS configuration for the server based on a dynamically generated, self-signed certificate.